@@ -1,12 +1,14 @@
-import torch
-from pytorch_lightning.callbacks import Callback
-from nomic import atlas, AtlasUser
-from loguru import logger
-from typing import List, Dict
 from collections import defaultdict
 from datetime import datetime
+from typing import Dict, List
 
 import numpy as np
+import torch
+from loguru import logger
+from pytorch_lightning.callbacks import Callback
+
+from nomic import AtlasUser, atlas
+
 
 class AtlasLightningContainer:
     def __init__(self):
@@ -17,11 +19,11 @@ class AtlasLightningContainer:
         '''Log a batch of embeddings and corresponding metadata for each embedding.'''
         assert isinstance(embeddings, torch.Tensor), 'You must log a torch Tensor'
 
-        #ensure passed in embeddings are a tensor with shape (batch_size, dimension)
+        # ensure passed in embeddings are a tensor with shape (batch_size, dimension)
         if len(embeddings.shape) != 2:
             raise ValueError("Your logged embedding tensor must have shape (N,d)")
 
-        #sanity check the inputs
+        # sanity check the inputs
         for key in metadata:
             if isinstance(metadata[key], torch.Tensor):
                 metadata[key] = metadata[key].flatten().cpu().tolist()
@@ -29,12 +31,17 @@ class AtlasLightningContainer:
                 metadata[key] = metadata[key].flatten().tolist()
             else:
                 if not isinstance(metadata[key], list):
-                    if isinstance(metadata[key], float) or isinstance(metadata[key], int) or isinstance(metadata[key], str):
+                    if (
+                        isinstance(metadata[key], float)
+                        or isinstance(metadata[key], int)
+                        or isinstance(metadata[key], str)
+                    ):
                         metadata[key] = [metadata[key]]
 
-
             if embeddings.shape[0] != len(metadata[key]):
-                raise ValueError(f"Your metadata has invalid shape. You have {embeddings.shape[0]} embeddings but len(metadata['{key}']) = {len(metadata[key])}")
+                raise ValueError(
+                    f"Your metadata has invalid shape. You have {embeddings.shape[0]} embeddings but len(metadata['{key}']) = {len(metadata[key])}"
+                )
 
         self.embeddings.append(embeddings)
         for key in metadata:
@@ -45,12 +52,21 @@ class AtlasLightningContainer:
         self.embeddings = []
         self.metadata = defaultdict(list)
 
+
 class AtlasEmbeddingExplorer(Callback):
-    def __init__(self, max_points=-1, rebuild_time_delay=600, name=None, description=None, is_public=True, overwrite_on_validation=False):
+    def __init__(
+        self,
+        max_points=-1,
+        rebuild_time_delay=600,
+        name=None,
+        description=None,
+        is_public=True,
+        overwrite_on_validation=False,
+    ):
         '''
 
         Args:
-            max_points: The maximum points to visualize.
+            max_points: The maximum points to visualize. -1 will visualize all points.
             rebuild_time_delay: Only rebuilds the embedding explorer if 'rebuild_time_delay' seconds have passed since the last rebuild.
             name: The name for your embedding explorer.
             description: A description for your embedding explorer.
@@ -62,7 +78,7 @@ class AtlasEmbeddingExplorer(Callback):
         self.description = description
         self.is_public = is_public
         self.overwrite = overwrite_on_validation
-        self.project = None
+        self.dataset = None
         self.map = None
         self.atlas = AtlasLightningContainer()
         self.rebuild_time_delay = rebuild_time_delay
@@ -70,14 +86,13 @@ class AtlasEmbeddingExplorer(Callback):
 
     def on_train_start(self, trainer, pl_module):
         '''Verify that atlas is configured and set up variables'''
-        AtlasUser() #verify logged in.
+        AtlasUser()  # verify logged in.
         pl_module.atlas = self.atlas
 
     def on_sanity_check_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
         AtlasUser()  # verify logged in.
         pl_module.atlas = AtlasLightningContainer()
 
-
     def on_train_epoch_start(self, *args, **kwargs):
         self.atlas.clear()
 
@@ -95,10 +110,13 @@ class AtlasEmbeddingExplorer(Callback):
         if seconds_since_last_build < self.rebuild_time_delay:
             logger.info(
                 f"Skipping regenerating embedding explorer for this validation epoch as its been {seconds_since_last_build} seconds since the last rebuild and `rebuild_time_delay={self.rebuild_time_delay}`"
-                f" See your previous validation embedding space at: {self.map.map_link}")
+                f" See your previous validation embedding space at: {self.map.map_link}"
+            )
             return
         if not self.atlas.embeddings:
-            logger.info("Pytorch module does not have logits recorded in _atlas_logits property, AtlasEmbeddingExplorer will not generate a map.")
+            logger.info(
+                "Pytorch module does not have logits recorded in _atlas_logits property, AtlasEmbeddingExplorer will not generate a map."
+            )
             return
         embeddings = torch.cat(self.atlas.embeddings).detach().cpu().numpy()
 
@@ -106,11 +124,11 @@ class AtlasEmbeddingExplorer(Callback):
         assert set(lengths) != 1, 'Error in logging metadata, it is not all the same length'
 
         if self.max_points > 0:
-            embeddings = embeddings[:self.max_points, :]
+            embeddings = embeddings[: self.max_points, :]
             for key in self.atlas.metadata:
-                self.atlas.metadata[key] = self.atlas.metadata[key][:self.max_points]
+                self.atlas.metadata[key] = self.atlas.metadata[key][: self.max_points]
 
-                #convert all uniqish values to strings prior to insertion into Atlas so
+                # convert all uniqish values to strings prior to insertion into Atlas so
                 if len(set(self.atlas.metadata[key])) <= 10:
                     self.atlas.metadata[key] = [str(x) for x in self.atlas.metadata[key]]
 
@@ -125,26 +143,28 @@ class AtlasEmbeddingExplorer(Callback):
         for key in keys:
             if key == 'id':
                 continue
-            if isinstance(metadata[0][key], float) or \
-                    isinstance(metadata[0][key], int) or \
-                    key in ('class', 'label', 'target') or \
-                    len(set(self.atlas.metadata[key])) <= 10:
+            if (
+                isinstance(metadata[0][key], float)
+                or isinstance(metadata[0][key], int)
+                or key in ('class', 'label', 'target')
+                or len(set(self.atlas.metadata[key])) <= 10
+            ):
                 colorable_fields.append(key)
 
         try:
-            project = atlas.map_embeddings(embeddings=embeddings,
-                                            data=metadata,
-                                            id_field='id',
-                                            colorable_fields=colorable_fields,
-                                            is_public=self.is_public,
-                                            name=self.name,
-                                            description=self.description,
-                                            reset_project_if_exists=self.overwrite,
-                                            build_topic_model=False)
+            project = atlas.map_data(
+                embeddings=embeddings,
+                data=metadata,
+                id_field='id',
+                is_public=self.is_public,
+                name=self.name,
+                description=self.description,
+                build_topic_model=False,
+            )
         except BaseException as e:
             logger.info(e)
             logger.info("Failed to update your map on this validation epoch.")
             return
-        self.project = project
+        self.dataset = project
         self.map = project.maps[0]
-        self.last_rebuild_timestamp = datetime.now()
\ No newline at end of file
+        self.last_rebuild_timestamp = datetime.now()
